pub struct DMSCQueueModule { /* private fields */ }Expand description
Main queue module implementing the async service module trait.
This module provides the main entry point for the queue system, integrating with the DMSC service module system for lifecycle management.
Implementations
Sourceimpl DMSCQueueModule
impl DMSCQueueModule
Sourcepub async fn new(config: DMSCQueueConfig) -> DMSCResult<Self>
pub async fn new(config: DMSCQueueConfig) -> DMSCResult<Self>
Sourcepub fn with_config(_config: DMSCQueueConfig) -> DMSCResult<Self>
pub fn with_config(_config: DMSCQueueConfig) -> DMSCResult<Self>
Sourcepub fn queue_manager(&self) -> Arc<DMSCQueueManager>
pub fn queue_manager(&self) -> Arc<DMSCQueueManager>
Returns a reference to the queue manager.
Returns
An Arc